@@ -10,12 +10,13 @@ try
 
     imsg << "Passing `" << dir << "' to glob" << endl;
 
-    Glob glob(dir, Glob::NOSORT, Glob::DEFAULT);    // find matching elements
+                                                    // find matching elements
+    Glob glob(Glob::DIRECTORY, dir, Glob::NOSORT, Glob::DEFAULT);
 
     for (auto entry: glob)
         globFilter(entry, context);                 // accept unique dirs.
 }
-catch (Errno const &err)      // to catch exception from glob
+catch (exception const &exc)
 {}
 
 
