@@ -6,15 +6,10 @@ void Alternatives::globFrom(string initial)
 
     if (not d_arg.option('a'))
     {
-        auto iterators = d_arg.beginEndRE("^\\s*ignore\\s+\\S+\\s*$");
+        auto iters = d_arg.beginEndRE("^\\s*ignore\\s+\\S+\\s*$");
         
-        for_each(
-            iterators.first, iterators.second, 
-            [&](std::string const &line)
-            {
+        for (auto &line: ranger(iters.first, iters.second))
                 addIgnored(line, context.ignore);
-            }
-        );
     }
 
     void (Alternatives::*globFun)(string dir, GlobContext &context) = 
